==> cdk_2.7.1.orig.tar.gz: cdk-cdk-2.7.1/base/interfaces/src/main/java/org/openscience/cdk/interfaces/IPDBMonomer.java <==
/* Copyright (C) 2006-2007  Miguel Rojas <miguel.rojas@uni-koeln.de>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.interfaces;

/**
 * Represents the idea of an protein monomer as found in PDB files.
 *
 * @cdk.module  interfaces
 * @cdk.githash
 *
 * @author Miguel Rojas &lt;miguel.rojas@uni-koeln.de&gt;
 * @cdk.created 2006-11-20
 *
 * @cdk.keyword pdbpolymer
 */
public interface IPDBMonomer extends IMonomer {

    /**
     * Sets the ICode of this monomer.
     *
     * @param newICode  the I code of this monomer
     */
    public void setICode(String newICode);

    /**
     * Gets the ICode of this monomer.
     *
     * @return the ICode of this monomer
     */
    public String getICode();

    /**
     * Sets the Chain ID of this monomer.
     *
     * @param newChainID  the Chain ID of this monomer
     */
    public void setChainID(String newChainID);

    /**
     * Gets the Chain ID of this monomer.
     *
     * @return the Chain ID of this monomer
     */
    public String getChainID();

    /**
     * Gets the sequence identifier of this monomer.
     *
     * @return  the sequence identifier of this monomer
     */
    public String getResSeq();

    /**
     * Sets the sequence identifier of this monomer.
     *
     * @param newResSeq  the new sequence identifier of this monomer
     */
    public void setResSeq(String newResSeq);

    /**
     *{@inheritDoc}
     */
    @Override
    public IPDBMonomer clone() throws CloneNotSupportedException;
}

==> cdk_2.9.orig.tar.gz: cdk-cdk-2.9/base/interfaces/src/main/java/org/openscience/cdk/interfaces/IPDBMonomer.java <==
/* Copyright (C) 2006-2007  Miguel Rojas <miguel.rojas@uni-koeln.de>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.interfaces;

/**
 * Represents the idea of an protein monomer as found in PDB files.
 *
 * @cdk.module  interfaces
 * @cdk.githash
 *
 * @author Miguel Rojas &lt;miguel.rojas@uni-koeln.de&gt;
 * @cdk.created 2006-11-20
 *
 * @cdk.keyword pdbpolymer
 */
public interface IPDBMonomer extends IMonomer {

    /**
     * Sets the ICode of this monomer.
     *
     * @param newICode  the I code of this monomer
     */
    void setICode(String newICode);

    /**
     * Gets the ICode of this monomer.
     *
     * @return the ICode of this monomer
     */
    String getICode();

    /**
     * Sets the Chain ID of this monomer.
     *
     * @param newChainID  the Chain ID of this monomer
     */
    void setChainID(String newChainID);

    /**
     * Gets the Chain ID of this monomer.
     *
     * @return the Chain ID of this monomer
     */
    String getChainID();

    /**
     * Gets the sequence identifier of this monomer.
     *
     * @return  the sequence identifier of this monomer
     */
    String getResSeq();

    /**
     * Sets the sequence identifier of this monomer.
     *
     * @param newResSeq  the new sequence identifier of this monomer
     */
    void setResSeq(String newResSeq);

    /**
     *{@inheritDoc}
     */
    @Override
    IPDBMonomer clone() throws CloneNotSupportedException;
}
